#[non_exhaustive]pub enum MssqlVersion {
SqlServer2016,
SqlServer2017,
SqlServer2019,
SqlServer2022,
SqlServer2025,
}Expand description
SQL Server engine version targeted by planning.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
SqlServer2016
SQL Server 2016.
SqlServer2017
SQL Server 2017.
SqlServer2019
SQL Server 2019.
SqlServer2022
SQL Server 2022.
SqlServer2025
SQL Server 2025.
Implementations
Sourceimpl MssqlVersion
impl MssqlVersion
Sourcepub const fn default_compatibility_level(self) -> CompatibilityLevel
pub const fn default_compatibility_level(self) -> CompatibilityLevel
Returns the default database compatibility level for this SQL Server engine version.
Sourcepub const fn supports_compatibility_level(
self,
compatibility_level: CompatibilityLevel,
) -> bool
pub const fn supports_compatibility_level( self, compatibility_level: CompatibilityLevel, ) -> bool
Returns whether this SQL Server engine version supports the database compatibility level.