Module profile

Module profile 

Benchmark-only write profiling hooks. Benchmark-only profiling support for the write path.

Structs

DirectDateFastPathOverride
Scoped benchmark override that disables the direct date fast path.
DirectFixedWidthFastPathOverride
Scoped benchmark override that disables the whole fixed-width fast path.
DirectWriteProfile
Accumulated timings for the direct raw writer path.

Functions

disable_direct_date_fast_path_for_scope
Disables direct date fixed-width fast-path encoding for the current scope.
disable_direct_fixed_width_fast_path_for_scope
Disables direct fixed-width fast-path encoding for the current scope.
finish_direct_write_profile
Stops direct writer profiling on the current thread and returns the data.
start_direct_write_profile
Starts direct writer profiling on the current thread.