pub fn finish_direct_write_profile() -> Option<DirectWriteProfile>Expand description
Stops direct writer profiling on the current thread and returns the data.
pub fn finish_direct_write_profile() -> Option<DirectWriteProfile>Stops direct writer profiling on the current thread and returns the data.